#
# spec file for package ubuntu-themes
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ubuntu-themes
Version:        20.10
Release:        2.5
Summary:        Eyecandy from Ubuntu
License:        GPL-3.0-or-later
URL:            https://launchpad.net/ubuntu-themes
Source:         https://launchpad.net/ubuntu/+archive/primary/+files/%{name}_%{version}.orig.tar.gz
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildArch:      noarch
BuildRequires:  python3
BuildRequires:  python3-xml

%description
Ubuntu GNU/Linux basic artwork.

%package -n metatheme-ambiance-common
Summary:        Ambiance Gtk Theme -- Common Files
Recommends:     humanity-icon-theme
Recommends:     ubuntu-mono-icon-theme
Suggests:       gtk2-metatheme-ambiance
Suggests:       gtk3-metatheme-ambiance

%description -n metatheme-ambiance-common
Includes an Ambiance light-on-dark theme.

Introduced as the default theme in Ubuntu 10.04 LTS.

%package -n metatheme-radiance-common
Summary:        Radiance Gtk Theme -- Common Files
Recommends:     humanity-icon-theme
Recommends:     ubuntu-mono-icon-theme
Suggests:       gtk2-metatheme-radiance
Suggests:       gtk3-metatheme-radiance

%description -n metatheme-radiance-common
Includes an Radiance dark-on-light theme.

Introduced as one of the defaults in Ubuntu 10.04 LTS.

%package -n gtk2-metatheme-ambiance
Summary:        Ambiance Gtk Theme -- GTK+ 2 Support
Requires:       gtk2-engine-murrine >= 0.90.3
Requires:       metatheme-ambiance-common = %{version}
Supplements:    (metatheme-ambiance-common and gtk2)

%description -n gtk2-metatheme-ambiance
Includes an Ambiance light-on-dark theme.

Introduced as the default theme in Ubuntu 10.04 LTS.

%package -n gtk2-metatheme-radiance
Summary:        Radiance Gtk Theme -- GTK+ 2 Support
Requires:       gtk2-engine-murrine >= 0.90.3
Requires:       metatheme-radiance-common = %{version}
Supplements:    (metatheme-radiance-common and gtk2)

%description -n gtk2-metatheme-radiance
Includes an Radiance dark-on-light theme.

Introduced as one of the defaults in Ubuntu 10.04 LTS.

%package -n gtk3-metatheme-ambiance
Summary:        Ambiance Gtk Theme -- GTK+ 3 Support
Requires:       gtk3
Requires:       metatheme-ambiance-common = %{version}
Supplements:    (metatheme-ambiance-common and gtk3)

%description -n gtk3-metatheme-ambiance
Includes an Ambiance light-on-dark theme.

Introduced as the default theme in Ubuntu 10.04 LTS.

%package -n gtk3-metatheme-radiance
Summary:        Radiance Gtk Theme -- GTK+ 3 Support
Requires:       metatheme-radiance-common = %{version}
Supplements:    (metatheme-radiance-common and gtk3)

%description -n gtk3-metatheme-radiance
Includes an Radiance dark-on-light theme.

Introduced as one of the defaults in Ubuntu 10.04 LTS.

%package -n ubuntu-mono-icon-theme
Summary:        Ubuntu Mono Icon theme
Requires:       adwaita-icon-theme
Requires:       hicolor-icon-theme
Requires:       humanity-icon-theme
Provides:       ubuntu-mono = %{version}

%description -n ubuntu-mono-icon-theme
Dark and Light panel icons to make desktop beautiful.

%prep
%setup -q

sed -i '1s|^#!.*$|#!%{_bindir}/python3|' *.py

%build
%make_build

%install
mkdir -p %{buildroot}%{_datadir}/themes/ %{buildroot}%{_datadir}/icons/
for theme in Ambiance Radiance; do
    cp -a $theme %{buildroot}%{_datadir}/themes/$theme
done
for i in ubuntu-mono-dark ubuntu-mono-light LoginIcons; do
    mkdir -p %{buildroot}%{_datadir}/icons/$i
    for d in $(find $i -type d); do
      mkdir -p %{buildroot}%{_datadir}/icons/${d}
    done
    for icon in $(find $i -type f); do
      real_icon=$(readlink -f $icon)
      cp -r ${real_icon} %{buildroot}%{_datadir}/icons/${icon}
    done
done
%icon_theme_cache_create_ghost ubuntu-mono-dark
%icon_theme_cache_create_ghost ubuntu-mono-light
%icon_theme_cache_create_ghost LoginIcons
%fdupes %{buildroot}%{_datadir}/themes/Ambiance/
%fdupes %{buildroot}%{_datadir}/themes/Radiance/
%fdupes %{buildroot}%{_datadir}/icons/

%files -n metatheme-ambiance-common
%license COPYING
%{_datadir}/themes/Ambiance/
%exclude %{_datadir}/themes/Ambiance/gtk-?.*/

%files -n metatheme-radiance-common
%license COPYING
%{_datadir}/themes/Radiance/
%exclude %{_datadir}/themes/Radiance/gtk-?.*/

%files -n gtk2-metatheme-ambiance
%{_datadir}/themes/Ambiance/gtk-2.*/

%files -n gtk2-metatheme-radiance
%{_datadir}/themes/Radiance/gtk-2.*/

%files -n gtk3-metatheme-ambiance
%{_datadir}/themes/Ambiance/gtk-3.*/

%files -n gtk3-metatheme-radiance
%{_datadir}/themes/Radiance/gtk-3.*/

%files -n ubuntu-mono-icon-theme
%license COPYING
%ghost %{_datadir}/icons/ubuntu-mono-dark/icon-theme.cache
%ghost %{_datadir}/icons/ubuntu-mono-light/icon-theme.cache
%ghost %{_datadir}/icons/LoginIcons/icon-theme.cache
%{_datadir}/icons/ubuntu-mono-dark
%{_datadir}/icons/ubuntu-mono-light
%{_datadir}/icons/LoginIcons/

%changelog
* Tue Dec 27 2022 Jan Ritzerfeld <suse@bugs.jan.ritzerfeld.org>
- Added missing empty directories, e.g.:
  * /usr/share/icons/ubuntu-mono-dark/apps/48/
  * /usr/share/icons/ubuntu-mono-light/apps/48/
* Tue Apr 19 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 20.10
  * Set color for gnome-flashback desktop icons.
  * Build requires python3 instead of python2
* Tue Mar  2 2021 Marguerite Su <i@marguerite.su>
- fix tumbleweed build
* Wed Feb 26 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 19.04 (changes since 16.10~bzr20180122):
  * Remove an old workaround which would force combobox menu text
    (lp#1725921).
  * list, row: Set padding, use white bg and hover effect on
    activatable (lp#1755351, lp#1757471).
  * Ambiance: Add proper theming for horizontal and vertical linked
    items.
  * Ambiance, Radiance: Use proper border-width for first/last
    linked buttons in rtl.
  * Ambiance, Radiance: Use default backdrop colours for views and
    progress bars.
  * Ambiance, Radiance: Implement ambiance-rw inspired darker
    placessidebar.
  * Ambiance, Radiance: Theme the places sidebar buttons to match
    parent.
  * Ambiance, Radiance: Remove the gap between the popover and tip,
    add border.
  * Ambiance, Radiance: use static bg imgs for window buttons and
    add padding (lp#1693609).
  * Ambiance, Radiance: don't use any background image (gradient)
    when in backdrop.
  * Ambiance, Radiance: Add more specific selectors for scale
    states (lp#1759481).
  * Ambiance, Radiance: Set top and bottom margins for switch and
    separators in headerbar (lp#1693474).
  * Ambiance, Radiance: Review of pathbar and stackswitcher buttons
    (lp#1765561).
  * Ambiance, Radiance: Add missing global colour definitions
    (lp#1759795, lp#1762841).
  * Ambiance, Radiance: Fix complex headerbars such as
    gnome-builder one (lp#1762783).
  * Ambiance, Radiance: No need to add icon-shadow for appmenu.
  * Ambiance, Radiance: Add some transparency to links colour when
    in backdrop.
  * Ambiance, Radiance: Uniform the bg colour of decoration and
    menubar (lp#1759754).
  * Ambiance, Radiance: Use proper colours for drop actions on
    places sidebar (lp#1707606).
  * Ambiance, Radiance: Define colour for infobar and implement
    backdrop state (lp#1765882)
  * Remove nonexistent gnome-builder.css (lp#1773045).
  * Radiance: Fix typo in assets link for focused buttons
    (lp#1781736).
  * Radiance: Use scaled image for buttons border (lp#1781736).
  * Ambiance, Radiance: Don't use padding on window buttons for
    chromium (lp#1782038).
  * Ambiance: Use default foreground colour for toolbar menus
    (lp#1758841).
  * Ambiance, Radiance: Show proper arrow in combobox (lp#1743373).
  * Ambiance, Radiance: Use default disabled colour for actions
    headerbar buttons (lp#1785699).
  * Ambiace, Radiance: Use headerbar destructive-action definition
    for buttons.
  * Ambiance, Radiance: Fix list selected colour for gnome-boxes
    (lp#1761684).
  * Ambiance, Radiance: Properly theme disabled and hovered
    accelerators (lp#1795895).
  * Don't use icon hover bg colour on nemo desktop (lp#1814506).
- Drop support for old openSUSE versions.
* Mon Mar 12 2018 sor.alexei@meowr.ru
- Update to version 16.10~bzr20180122 (changes since
  16.10~bzr20171115):
  * Ambiance, Radiance: Fix focus ring for combo boxes.
  * Ambiance, Radiance: Fix link button mouseover.
  * Ambiance, Radiance: Fix checkbutton and radiobutton highlight.
  * Ambiance, Radiance: Fixed grey background appearing in step
    fields.
- Build with Python2 explicitly.
* Sat Nov 18 2017 sor.alexei@meowr.ru
- Update to version 16.10~bzr20171115 (changes since
  16.10~bzr20170510):
  * Ambiance, Radiance: Keep the windows button closer.
  * Ambiance, Radiance: Set proper min-height for message dialogue
    decorations.
  * Ambiance, Radiance: Define theme_* colours based on ours.
  * Ambiance, Radiance: Handle .titlebar separator as headerbar one.
  * Ambiance, Radiance: Apply toolbar style to headerbars that are
    not child or are not .titlebar's (lp#1689239).
  * Ambiance, Radiance: Don't apply the toolbar style to headerbars
    or titlebars.
  * Vertically centre widgets in the header bar (lp#1693613).
  * Fix the ubuntu-mono-dark battery icons to avoid distortion in
    GNOME Shell and MATE (lp#1693155).
  * Rename most battery icons prepending unity-*. As the battery
    icons in ubuntu-mono aren't square, we want to special case
    them (lp#1711085).
  * Add support for GtkTextView::monospace (lp#1700218).
  * Fix support GtkTreeView separators (lp#1701512).
  * Make dimmed text more visible in GNOME Boxes with Ambiance
    (lp#1700100).
  * Add support for vertically linked buttons (lp#1708141).
  * Radiance: Use proper button border-image-source for headerbar
    elements (lp#1692925).
  * Ambiance, Radiance: Ignore titlebutton theming for appmenu.
  * Ambiance, Radiance: Add better definition for button
    destructive-action (lp#1697900).
  * Fix misaligned Entry widget borders (lp#1712996).
  * Ambiance, Radiance: Fix vertical linked buttons borders,
    corners and backgrounds (lp#1718234).
  * Ambiance, Radiance: Be less restrictive in setting headerbar
    minimum height (lp#1712011).
  * Ambiance,Radiance: Refactor .titlebar theming to properly
    support headerbar children (lp#1716143).
  * Ambiance/Radiance/*/gtk-widget.css: Make primary action button
    (suggested action) in headerbar more visible (lp#1709500).
  * Make suggested actions disable style like other buttons (no
    grey disabled button) to not appear unthemed (lp#1720570).
  * Fix traditional decorations offset when window toggle beetween
    focus to unfocus when maximised (lp#1720980).
  * Fix suggested actions hovering colour on unfocused window.
  * Ambiance, Radiance: Use toolbar-mode gradients on titlebars for
    maximised windows (lp#1717023, lp#1721440).
  * Ambiance, Radiance: Notebook active tab uses wrong gradient
    when in backdrop.
  * Ambiance, Radiance: Fix gradients for suggested-action hover,
    active and backdrop states.
  * gtk2: Ambiance, Radiance: Inherit style fixes from MATE themes
    (lp#961679).
  * Fix osd progress bar look (lp#1724808).
  * Ambiance, Radiance: Fix horizontal linked suggested-action and
    destructive-action (lp#1721102).
  * Ambiance, Radiance: Fixed border in switcher widget (lp#1719355).
  * Ambiance, Radiance (gtk2): Remove undefined "murrine-scrollbar"
    from mate-panel (lp#1723422).
  * Ambiance, Radiance: Add theming for headerbar
    .destructive-action button's (lp#1726318)..
  * Ambiance, Radiance: Use inverted gradient for button actions in
    maximised titlebars (lp#1726322).
  * Suru icon theme update.
- Remove themes-mate-panel.patch: no longer needed.
* Thu May 11 2017 sor.alexei@meowr.ru
- Update to version 16.10~bzr20170510 (changes since
  16.10~bzr20161007):
  * Dim images of insensitive widgets (lp#1578810).
  * Fix some deprecation warnings with GTK+ 3.22.
  * [Suru icons] Add a mono icon for launcher settings, called
    "preferences-desktop-launcher-symbolic".
  * [Suru icons] Add wired network indicators and new states for
    the VPN indicators. Update designs for error states.
  * Style ".dim-label" for gnome-software.
  * gnome-panel.css: Remove the shadow on the right side of the
    panel.
  * Update gnome-panel.css for compatibility with GNOME Panel 3.24.
  * Fix shadows, handlers, decorations look for CSD and SSD in
    GNOME Shell (lp#1685271, lp#1685272, lp#1689239).
* Sun Oct 23 2016 sor.alexei@meowr.ru
- Update to version 16.10~bzr20161007 (changes since
  16.10~bzr20160804):
  * [Suru icons] Add an ownCloud icon for online accounts
    (lp#1571587).
  * Update styling for gnome-panel 3.20+.
  * Radiance: Fix colours and clock applet shadow for gnome-panel.
  * gedit: Don't set a border on the 'x of y' thing in the search
    results.
  * Set a proper minimum width on levelbar troughs.
  * gnome-panel: Don't apply the gnome-menubar rules to unity
    decorations and panel too (lp#1617371).
  * Remove box-shadow from .background:backdrop.
  * Fix jumping menu items (lp#1617415).
  * Add styling for gnome-flashback: OSD windows, input source
    switching, candidate popups and monitor labels.
  * Fix gtk3 toolbar theming for LibreOffice (lp#1580537).
  * Fix combobox menus having a black line down the left hand side.
  * Fix some syntax errors, and use a maintainer script to move the
    Radiance/gtk-3.0/assets directory to a symlink.
  * Improvements for HiDPI. Includes new icons and moves a lot of
    assets to use gtk-scaled to suit both normal and hidpi
    resolutions (lp#1549490)
  * gnome-panel.css: Fix weather applet text color (lp#1629983).
  * Fix borders of LibreOffice toolbars, so that they don't
    overlap the window decorations (lp#1624571).
* Wed Aug 10 2016 sor.alexei@meowr.ru
- Update to version 16.10~bzr20160804 (changes since
  14.04~bzr20160613):
  * [Suru icons] Add view-rotate icon for Media Services.
  * Add new CSS to style progress bars based on colours rather
    than images. This fixes the "empty progress bars" bug
    (lp#1052936).
  * Add specific border widths to left and right of GtkSwitch
    buttons to hide the overflowing background of the button
    (lp#1594816).
  * [Suru icons] Add the keyboard indicators in a dedicated
    directory.
  * [Suru icons] Add mono arrow icons for the toolkit widgets: up,
    down, left, right and scrollbar stepper.
  * Simplify Metacity theme by replacing solid colour image with
    filled rectangle to improve HiDPI support (lp#1603218).
  * Ambiance, Radiance: Port to work with GTK+ 3.20 (lp#1593048).
* Fri Jun 17 2016 sor.alexei@meowr.ru
- Update to version 14.04~bzr20160613:
  * [Suru icons] Add location indicator icons for inactive, idle
    and active states (lp#1407921).
* Fri May 27 2016 sor.alexei@meowr.ru
- Update to version 14.04~bzr20160426:
  * [Suru icons] Update the calendar mono icon to a more generic
    design (removed the digits). Add or updated another action and
    indicator mono icons (lp#1362962).
* Tue Apr 19 2016 sor.alexei@meowr.ru
- Update to version 14.04~bzr20160415:
  * Add 1px padding to calendar widget elements; looks better.
  * Suru icon theme: Normalisation of arrows used in mono icons,
    plus minor additions or updates to existing designs (lp#1518934).
  * Add these fixes for Calendar: lp#1551744, lp#1558659.
* Mon Apr 11 2016 sor.alexei@meowr.ru
- Update to version 14.04~bzr20160324.1:
  * Ambiance, Radiance: use inverted gradient in headerbar when in
    toolbar-mode (lp#1515810).
  * Reduce the padding on flat entries, that's needed with Gtk 3.18
    otherwise the entry is displayed over new rows in listview when
    editing, that's also what the Gtk upstream themes are doing.
  * Show the cursor index better in Totem videos (lp#1545026).
  * Override box shadow and border settings for linked dialog
    buttons so they don't looked mashed together. Extra border
    radius is required to stop the button background bleeding
    through the border (lp#1513856).
- Remove themes-csd-titlebar-fix.patch.
* Fri Mar  4 2016 sor.alexei@meowr.ru
- Update to 14.04~bzr20160209:
  * gnome-terminal: Fix scrollbar background (lp#1539055).
* Mon Jan 25 2016 sor.alexei@meowr.ru
- Update to 14.04~bzr20160120:
  * Scrollbars: Fix through drawing on webkit.
* Sat Dec 19 2015 sor.alexei@meowr.ru
- Update to 14.04~bzr20151216 (changes since 14.04~bzr20151127):
  * Suru icon theme update: Inclusion of SDK icons Addition of a
    whole set of mono device icons Updated app icons designs
    (lp#1518934).
  * Basic "app-notification" theming to avoid weirdness in Nautilus.
  * Update the nautilus.css with the current upstream one, it could
    probably be tweaked a bit and has references to color used
    upstream but those don't look out of place with our theme and
    is better than what we have now.
* Sat Nov 28 2015 sor.alexei@meowr.ru
- Update to 14.04~bzr20151127:
  * Adds padding to sidebar icons (lp#1515557).
  * Revised theme support for new version of gedit.
* Mon Oct  5 2015 sor.alexei@meowr.ru
- Update to 14.04~bzr20151001:
  * osd: style free-floating osd buttons (lp#1466890, lp#1500844).
  * Add a new VPN indicator and a bunch of new mono icons.
* Sun Sep 13 2015 sor.alexei@meowr.ru
- Update to 14.04~bzr20150910 (changes since 14.04~bzr20150813):
  * Style software-center's action bar again.
  * Ambiance, Radiance: make overlay scrollbars to look more like
    the Ubuntu designed ones (lp#1450747, lp#1493607).
- Remove themes-scrollbar-fixes.patch.
* Mon Aug 17 2015 sor.alexei@meowr.ru
- Update to 14.04~bzr20150813:
  * This update include a few bug fixes that we chased during our
    design team bug sprint in August 2015: essentially a bunch of
    new mono icons and updated existing designs (lp#1367137,
    lp#1478025, lp#1294251, lp#1424819, lp#1431876).
* Wed Jul 22 2015 sor.alexei@meowr.ru
- Update to 14.04~bzr20150721 (changes since 14.04~bzr20150707):
  * Clean up nautilus theming. Mostly, this consists of moving from
    nautilus-specific widgets and classes to more generic gtk ones
    (lp#1463848).
  * Theme GTK+ overlay-scrollbars to be more ubuntu-ish.
* Sat Jul 11 2015 sor.alexei@meowr.ru
- Update to 14.04~bzr20150707 (changes since 14.04~bzr20150603):
  * Updated the app icons to their new version (flatter and
    refreshed graphic style) and added a new icon for Dekko email
    client. Changed the colour of the 'new message' indicator to
    green (lp#1457424, lp#1450894)
  * Updated all mono icons to the new thinner graphic style,
    including actions, indicators and symbolic app and device icons.
* Thu Jun  4 2015 sor.alexei@meowr.ru
- Update to 14.04~bzr20150603 (changes since 14.04~bzr20150410):
  * Set :link colour.
  * Style under- and overshoot.
  * Cherrypick the new messages-new.svg suru icon from
    lp:~tiheum/ubuntu-themes/suru-app-icons-v2.
* Sun Apr 12 2015 sor.alexei@meowr.ru
- Update to 14.04~bzr20150410:
  * Draw shadows for menus.
  * Do not use symbolic colours for style.
* Sun Apr  5 2015 sor.alexei@meowr.ru
- Update to 14.04~bzr20150331 (changes since 14.04~bzr20150319):
  * Add some style info for lightdm-unity-greeter buttons
    (lp#1423542, lp#1423542).
  * Radiance: fix radio mark colouring in menus.
  * Set the background on GtkStack widgets (lp#1285783).
* Fri Mar 20 2015 sor.alexei@meowr.ru
- Update to 14.04~bzr20150319:
  * Enhance header bar styling.
  * Style overlay widgets needed by Totem.
* Thu Feb 12 2015 sor.alexei@meowr.ru
- Initial package.
